@@ -493,6 +493,7 @@ fuse = function(input, output = NULL, text = NULL, envir = parent.frame(), quiet
   set_path('fig.path'); set_path('cache.path')
 
   .env$input = input
+  if (is_file(input)) .env$full_input = normalizePath(input)
   res = .fuse(blocks, input, quiet)
 
   # save timing data if necessary
@@ -746,7 +747,7 @@ fuse_code = function(x, blocks) {
   p3 = unlist(p2)  # vector of plot paths
   # get the relative path of the plot directory
   fig.dir = if (length(p3)) tryCatch(
-    sub('^[.]/', '.', paste0(dirname(relative_path(p3[1], .env$wd_out)), '/')),
+    sub('^[.]/', '', paste0(dirname(relative_path(p3[1], .env$wd_out)), '/')),
     error = function(e) NULL
   )
 
@@ -820,9 +821,12 @@ fuse_code = function(x, blocks) {
       } else fenced_block(x, a, fence)
     }
   })
+  out = dropNULL(out)
 
   # collapse a code block without attributes into previous adjacent code block
-  if (isTRUE(opts$collapse) && (n <- length(res)) > 1) {
+  # (also try to collapse for results = 'hide')
+  collapse = isTRUE(opts$collapse) || res_show == 'hide'
+  if (collapse && (n <- length(out)) > 1) {
     i1 = 1; k = NULL  # indices of elements to be removed from `out`
     for (i in 2:n) {
       if (i - i1 > 1) i1 = i - 1  # make sure blocks are adjacent
@@ -1093,7 +1097,7 @@ reactor(
   attr.source = NULL, attr.output = NULL, attr.plot = NULL, attr.chunk = NULL,
   attr.message = '.plain .message', attr.warning = '.plain .warning', attr.error = '.plain .error',
   cache = FALSE, cache.path = NULL,
-  dev = NULL, dev.args = NULL, fig.path = NULL, fig.ext = NULL,
+  dev = NULL, dev.args = NULL, fig.path = NULL, fig.ext = NULL, fig.keep = TRUE,
   fig.width = 7, fig.height = 7, fig.dim = NULL, fig.cap = NULL, fig.alt = NULL, fig.env = '.figure',
   tab.cap = NULL, tab.env = '.table', cap.pos = NULL,
   print = NULL, print.args = NULL, time = FALSE,
@@ -1117,7 +1121,7 @@ eng_r = function(x, inline = FALSE, ...) {
     return(fmt_inline(res, x$math))
   }
   args = reactor(
-    'fig.path', 'fig.ext', 'dev', 'dev.args', 'message', 'warning', 'error',
+    'fig.path', 'fig.ext', 'fig.keep', 'dev', 'dev.args', 'message', 'warning', 'error',
     'cache', 'print', 'print.args', 'verbose'
   )
   if (is.character(args$fig.path)) args$fig.path = paste0(args$fig.path, opts$label)
@@ -1125,7 +1129,7 @@ eng_r = function(x, inline = FALSE, ...) {
   # if fig.dim is provided, override fig.width and fig.height
   if (length(dm <- opts$fig.dim) == 2) size[] = as.list(dm)
   # map chunk options to record() argument names
-  names(args)[1:2] = c('dev.path', 'dev.ext')
+  names(args)[1:3] = c('dev.path', 'dev.ext', 'dev.keep')
   args = dropNULL(args)
   args$dev.args = merge_list(size, opts$dev.args)
   args$cache = list(
